@@ -2,6 +2,11 @@ import logging
 import re
 import socket
 
+try:
+    import ssl as _ssl
+except ImportError:
+    _ssl = None # No SSL support
+
 from kitnirc.events import NUMERIC_EVENTS
 from kitnirc.user import User
 
@@ -221,11 +226,16 @@ class Client(object):
         return False
 
     def connect(self, nick, username=None, realname=None, password=None,
-                host=None, port=6667):
+                host=None, port=6667, ssl=None):
         """Connect to the server using the specified credentials.
 
         Note: if host is specified here, both the host and port arguments
-        passed to Client.__init__ will be ignored."""
+        passed to Client.__init__ will be ignored.
+        
+        If the 'ssl' argument is boolean true, will use SSL. If it is a
+        dictionary, will both use SSL and pass the contents as kwargs to
+        the ssl.wrap_socket() call.
+        """
         if host:
             self.server = Host(host, port)
         if self.server is None:
@@ -238,6 +248,13 @@ class Client(object):
         _log.info("Connecting to %s as %s ...", self.server.host, nick)
 
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        if ssl and _ssl:
+            ssl_kwargs = ssl if isinstance(ssl, dict) else {}
+            self.socket = _ssl.wrap_socket(self.socket, **ssl_kwargs)
+        elif ssl:
+            _log.error("SSL requested but no SSL support available!")
+            return
+
         self.socket.connect((self.server.host, self.server.port))
         self.connected = True
 
@@ -335,6 +352,8 @@ class Client(object):
         be used in either a channel or in a PM, and responding to the person
         who invoked the command.
         """
+        if not isinstance(user, User):
+            user = User(user)
         if isinstance(incoming, User):
             self.msg(user, message)
         else:
@@ -392,7 +411,7 @@ class Client(object):
         """Quit the server (and stop the event loop).
 
         This actually just calls .disconnect() with the provided message."""
-        self.disconnect(message)
+        self.disconnect(message or "Bye")
 
     def kick(self, channel, nick, message=None):
         """Attempt to kick a user from a channel.
@@ -931,7 +950,7 @@ def _parse_nick(client, command, actor, args):
 @parser("INVITE")
 def _parse_invite(client, command, actor, args):
     """Parse an INVITE and dispatch an event."""
-    channel = args.rpartition(" ")
-    client.dispatch_event("INVITE", actor, channel)
+    target, _, channel = args.rpartition(" ")
+    client.dispatch_event("INVITE", actor, target, channel)
 
 # vim: set ts=4 sts=4 sw=4 et:
